/*

REPLICATION FILE FOR BEBER & BLATTMAN (2013), "THE LOGIC OF CHILD SOLDIERING AND COERCION"
December 2012

NOTES:
* Full replication materials for the entire Survey of War Affected Youth (SWAY) and all associated papers, including a data manual and full original surveys, are available at http://chrisblattman.com

* This replication package includes the following files, solely for replicaiton of the Beber and Blattman 2013 results:
1. SWAY_I&II_27Jan2009.dta: combined dataset
2. SWAY_I&II_ABD_Nov2010: combined abduction data
3. HHsurvey_sectionII_27May2008.dta: household survey data
4. SWAY_I_27Jan2009.dta: male dataset
5. SWAY_II_27Jan2009.dta: female dataset
6. Colombia.dta: adbuction data from Colombia
7. SL_data_revised.dta: abduction data from Sierra Leone	
8. liberia_data_revised.dta: abduction data from Liberia
9. sampling.csv: rebel sampling data
10. RebelGroupsData-1-13.csv: rebel groups data
 


INSTRUCTIONS FOR THIS DO FILE
1. Copy the full replication folder to your computer 
2. Update the link below in section 1.1 to point to the replication folder on your computer.
3. Note that the do-file will create temporary datasets in the Data/tempdata folder and output for Table 1 and Table 2 in the Data/Output folder.

TABLE OF CONTENTS

1.0 DATA PREPARATION
	1.1 *SET LINK TO REPLICATION FOLDER*
	1.2 *SET GLOBALS*
	1.3 *PREP "INDIVIDUAL" DATABASE FOR SWAY PHASES I AND II*
	1.4 *PREP "ABDUCTIONS" DATABASE FOR SWAY PHASES I AND II*
	1.5 *PREP DATA ON ABDUCTIONS AS A PROPORTION OF POPULATION, BY ABDUCTION AGE (USING SWAY HOUSEHOLD SURVEY)*
	1.6 *PREP RECRUITMENT DATABASES ACROSS REBEL GROUPS*
	1.7 *PREP REPRESENTATIVE CROSS-REBEL DATA*
2.0 *FIGURES*
	2.1 *FIGURE 6: Distribution of age at the time of abduction in the LRA*
	2.2 *FIGURE 7: Probability of being released in the first month of abduction, by age of abduction*
	2.3 *FIGURE 8: How do rebel leaders employ abductees of different ages?*
	2.4 *FIGURE 9: Average length of abduction, by age of abduction*
	2.5 *FIGURE 10: Ease of indoctrination and misinformation, by abduction age*
	2.6 *FIGURE 11: The distribution of child soldiering across 40 rebel groups (by level of coercion employed by the group)*
3.0 *TABLES*
3.1 *SUMMARY STATISTICS (not displayed in paper, but referred to in text)
3.2 *TABLE 1: Abduction experiences*
3.3 *TABLE 2: Correlates of child coercion across rebel groups*

*/


//1. DATA PREPARATION
clear
set mem 40m
set matsize 400
set more off

ssc install running, replace
ssc install outsum, replace

//1.1 *SET LINK TO REPLICATION FOLDER*
cd "[UPDATE]/SWAY Replication"

// 1.2 *SET GLOBALS*

	global ctrl "CC* Y* phase2 no_fthr96 no_mthr96 mthr_ed0 mthr_ed7 mthr_edhi fthr_ed0 fthr_ed7 fthr_edhi hh_cattle hh_cattle_2 hh_cattle_3 hh_cattle_4 hh_land hh_land_2 hh_land_3 hh_land_4 hh_size96 hh_size96_2 hh_size96_3 hh_size96_4 hh_stock hh_stock_2 hh_stock_3 hh_stock_4 hh_plow hh_fthr_frm"


// 1.3 *PREP "INDIVIDUAL" DATABASE FOR SWAY PHASES I AND II*

	use Data/SWAY_I&II_27Jan2009.dta, clear
	svyset [pw=i_weight], strata(stratum) psu(camp)
	
	* Generate new variables
	foreach y of varlist abd_lgth abd_age age hh_cattle hh_land hh_stock hh_size96 {
		gen `y'_2=`y'^2
		gen `y'_3=`y'^3
		gen `y'_4=`y'^4
		}
	
	gen phase2_abd_age = phase2*abd_age
	gen combatant=cond(fighter==1 | gun_k==1,1,0) if abd==1
	
	* Propensity score for abduction
	logit abd age age_2 age_3 age_4 C_* no_fthr96 no_mthr96 mthr_ed0 mthr_ed7 mthr_edhi fthr_ed0 fthr_ed7 fthr_edhi hh_cattle hh_cattle_2 hh_cattle_3 hh_cattle_4 hh_land hh_land_2 hh_land_3 hh_land_4 hh_size96 hh_size96_2 hh_size96_3 hh_size96_4 hh_stock hh_stock_2 hh_stock_3 hh_stock_4 hh_plow hh_fthr_frm [pw=i_weight] if phase2==0
      predict pscore_abd if phase2==0
      logit abd age age_2 age_3 age_4 C_* no_fthr96 no_mthr96 mthr_ed0 mthr_ed7 mthr_edhi fthr_ed0 fthr_ed7 fthr_edhi hh_cattle hh_cattle_2 hh_cattle_3 hh_cattle_4 hh_land hh_land_2 hh_land_3 hh_land_4 hh_size96 hh_size96_2 hh_size96_3 hh_size96_4 hh_stock hh_stock_2 hh_stock_3 hh_stock_4 hh_plow hh_fthr_frm [pw=i_weight] if phase2==1
      predict pscore_abd_2 if phase2==1
      replace pscore_abd = pscore_abd_2 if phase2==1
      drop pscore_abd_2
	
	gen labd_lgth=ln(abd_lgth)
	
	keep if abd==1 & found==1 & abd_age<=30

	* For variables measured only after two weeks, create alternative variables that impute value of zero for abductions <2w
	foreach y in magic command rewarded depend gun gun_keep fighter stay safer loyal loyal_often lead {
	    gen `y'_alt=`y'
	    replace `y'_alt=0 if `y'==.
	    }
	
	* For questions asked of one Phase only, replace zeros with missing values
	replace gun_alt=. if phase2==1
	replace gun_keep_alt=. if phase2==1
	replace fighter_alt=. if phase2==0
	replace rewarded_alt=. if phase2==1
	replace magic_alt=. if phase2==1
	replace command_alt=. if phase2==1
	replace depend_alt=. if phase2==1
	
	label var abd_age "Abduction age"
	label var abd_age_2 "Abduction age-squared"
	label var phase2_abd_age "Females x Abduction age"
	
	save Data/tempdata/individual.dta, replace
	

// 1.4 *PREP "ABDUCTIONS" DATABASE FOR SWAY PHASES I AND II*

	* Open "abductions" database (each row represents an abduction; each individual may have moree than one abduction)
	use Data/SWAY_I&II_ABD_Nov2010.dta, clear
	svyset [pw=i_weight], strata(stratum) psu(id)
	
	* Generate variables
	gen phase2_abd_age = phase2*abd_age
	foreach y of varlist abd_lgth abd_age age hh_cattle hh_land hh_stock hh_size96 {
		gen `y'_2=`y'^2
		gen `y'_3=`y'^3
		gen `y'_4=`y'^4
		}
	
	egen abd_age_std = std(abd_age)
	gen abd_age_std2 = abd_age_std^2
	
	replace esc_bat=0 if released==1 | rescued==1
	replace esc_bat=. if released_2==1
	replace esc_ran=0 if released==1 | rescued==1 
	replace esc_ran=. if released_2==1
	replace rescued=0 if released==1
	replace rescued=. if released_2==1
	
	*Drop non-abducted, unfound, and out-of-range
	keep if abd==1 & found==1 & abd_age<=30
	
	gen esc_knew_ran=esc_knew if esc_ran==1

	
	save Data/tempdata/abductions.dta, replace


// 1.5 *PREP DATA ON ABDUCTIONS AS A PROPORTION OF POPULATION, BY ABDUCTION AGE (USING SWAY HOUSEHOLD SURVEY)*
	
	* Infer population distribution from household data
	use Data/HHsurvey_sectionII_27May2008.dta, clear
	collapse (count) id [pw=hh_weight], by(age)
	
	* Generate a smoothed population distribution (to avoid clustering on approximate ages)
	running id2 age, mean span(.5) gen(pop) nog
	
	* Calculate population distribution in previous years
	drop id2
	gsort -age
	foreach n of numlist 1989/2004 {
		gen pop`n'=pop[_n-(2005-`n')]
		}
	
	* Save
	keep if age>=5 & age<=46
	drop pop
	sort age
	save Data/tempdata/pop.dta, replace
	
	* Prep Phase I dataset
	use Data/SWAY_I_27Jan2009.dta, clear
	keep hhiia IDENTIFYING_VARIABLES-age ABDUCTION_VARIABLES-abd3 ix2ayear ix2byear ix2cyear 
	ren ix2ayear abd_yr_a 
	ren ix2byear abd_yr_b
	ren ix2cyear abd_yr_c
	keep if found==1
	sort id2 hhiia
	save Data/tempdata/temp.dta, replace
	
	* Prep Phase II dataset
	use Data/SWAY_II_27Jan2009.dta, clear
	ren hh_id id2
	ren roster_row hhiia
	ren qix2aii abd_yr_a 
	ren qix2bii abd_yr_b
	ren qix2cii abd_yr_c
	keep hhiia IDENTIFYING_VARIABLES-age ABDUCTION_VARIABLES-abd3 abd_yr_a-abd_yr_c 
	keep if found==1
	drop abd_times
	sort id2 hhiia
	save Data/tempdata/temp2.dta, replace
	
	* Prep household dataset
	use Data/HHsurvey_sectionII_27May2008.dta, clear
	ren abd_age2 abd_age_2
	keep id2 hhiia-hhiil C_ach-abd_age_2 abd_times age hh_weight female
	foreach var of varlist C_ach-female {
	  ren `var' hh_`var'
	  }
	
	* Merge individual data into household data
	sort id2 hhiia
	merge id2 hhiia using Data/tempdata/temp.dta
	drop if _merge==2
	drop _merge
	
	sort id2 hhiia
	merge id2 hhiia using Data/tempdata/temp2.dta
	drop if _merge==2
	drop _merge
	
	* Replace missing data using household data
	replace age=hh_age if id==.
	replace abd=1 if hh_abd==1 & id==.
	replace abd_age_a=hh_abd_age1 if id==.
	replace abd_age_b=hh_abd_age_2 if id==.
	replace abd_lgth_a= hhiih_lgth if id==.
	replace abd_lgth_b=hhiii_lgth if id==.
	replace abd_yr_a=hhiih_yr if id==.
	replace abd_yr_b=hhiii_yr if id==.
	
	*Generate an abd_times variable
	gen abd_times=hh_abd_times
	replace abd_times=1 if abd==1 & abd_times<1
	replace abd_times=2 if abd2==1 & abd_times<2
	replace abd_times=3 if abd3==1 & abd_times<3

	duplicates drop id2 hhiia, force
	keep id2 hhiia hh_weight abd_age_* abd_yr_* abd_lgth_* abd abd_times hh_female
	
	* Create database of abductions for all household members
	reshape long abd_age_ abd_yr_ abd_lgth_, i(id2 hhiia) j(abdn) string
	ren abd_age_ abd_age
	ren abd_lgth_ abd_lgth
	ren abd_yr_ abd_yr
	
	* Abduction age
	gen abdage=round(abd_age)
	
	* Drop short abductions and too young/too old, and censor outlier years
	drop if abd==0
	drop if abd_lgth<=.25
	drop if abd_age<5 | abd_age>46
	replace abd_yr=1989 if abd_yr<1989
	replace abd_yr=2004 if abd_yr==2005
	
	save Data/AgeOfAbductionNov2010.dta, replace
	
	* Estimate number of abductions by abduction age and year
	collapse (count) id [pw=hh_weight], by(abdage abd_yr)
	drop if abd_yr==.
	ren id y
	reshape wide y, i(abdage) j(abd_yr)
	foreach y of varlist y1989-y2004 {
		replace `y'=0 if `y'==.
		}
	ren abdage age
	sort age
	
	* Merge with estimated population data
	merge age using Data/tempdata/pop.dta
	drop _merge
	
	* Estimate proportion of cohort abducted by abduction year
	foreach n of numlist 1989/2004 {
		gen abd`n'=y`n'/pop`n'
		}
	
	* Smooth abduction ages and collapse over abduction years
	sort age
	keep age y* abd*
	reshape long y abd, i(age) j(year)
	running abd age, ci gen(mn) nogr
	
	collapse (sum) y (mean) mn, by(age)
	egen abd=sum(y)
	gen prop=y/abd
	drop y abd
	
	save Data/tempdata/abduction_age, replace


// 1.6 *PREP RECRUITMENT DATABASES ACROSS REBEL GROUPS*

	* Calculate age of recruitment by faction in 12 rebel groups with survey data
	
		* Columbia
		use Data/Colombia.dta, clear
		gen faction=""
		replace faction="FARC (C)" if group_joined_first==2
		replace faction="ELM (C)" if group_joined_first==3
		replace faction="PARA (C)" if group_joined_first>=100 & group_joined_first<200
		drop if faction==""
		ren age_join age_recruit_faction
		gen abd=cond(motive_join==1,1,0)
		keep age_recruit_faction faction abd
		gen ctry = "Colombia"
		save Data/tempdata/Ctemp.dta, replace
		
		* Sierra Leone
		use Data/SL_data_revised.dta, clear
		ren faction_s3 faction
		replace faction="SLA (S)" if faction=="" & SLA==1
		replace faction="SLA (S)" if faction=="SLA"
		replace faction="RUF (S)" if faction=="" & RUF==1
		replace faction="RUF (S)" if faction=="RUF"
		replace faction="AFRC (S)" if faction=="" & AFRC==1
		replace faction="AFRC (S)" if faction=="AFRC"
		replace faction="CDF (S)" if faction=="" & CDF==1
		replace faction="CDF (S)" if faction=="CDF"
		replace faction="WSB" if faction=="" & WSB==1
		drop if faction=="WSB"
		ren recruit_abducted abd
		keep age_recruit_faction faction female abd
		gen ctry = "Sierra Leone"
		save Data/tempdata/SLtemp.dta, replace
		
		* Liberia
		use "Data/liberia_data_revised.dta", clear
		keep if Faction_Random==1 | Faction_Random==2 | Faction_Random==9 | Faction_Random==10 
		gen faction="NPFL (L)" if Faction_Random==1
		replace faction="AFL (L)" if Faction_Random==2
		replace faction="LURD (L)" if Faction_Random==9
		replace faction="MODEL (L)" if Faction_Random==10
		gen female=cond(gender==2,1,0)
		keep age_recruit_faction faction female abd
		gen ctry = "Liberia"
		save Data/tempdata/Ltemp.dta, replace
		
		*Uganda
		use Data/AgeOfAbductionNov2010.dta, clear
		gen age_recruit_faction=abdage
		gen faction="LRA (U)"
		gen ctry = "Uganda"
		ren hh_female female
		keep age_recruit_faction faction female ctry abd
	
	* Combine datasets
	append using Data/tempdata/SLtemp.dta
	append using Data/tempdata/Ltemp.dta
	append using Data/tempdata/Ctemp.dta
	
	*Create child recruitment indicators
	gen under18=cond(age_recruit_faction<18,1,0)
	gen under15=cond(age_recruit_faction<15,1,0)
	
	save Data/factions.dta, replace
	

// 1.7 *PREP REPRESENTATIVE CROSS-REBEL DATA*

	// CREATE DATASET
	
		* Import sampling data
		insheet using Data/sampling.csv, clear
		sort conflict_id
		save Data/sampling.dta, replace
		
		* Import rebel data 
		insheet using Data/RebelGroupsData-1-13.csv, clear

		* Merge in sampling data 
		sort conflict_id
		merge conflict_id using Data/sampling.dta
		tab _merge
		drop _merge
			
		* Generate Within-sample probability weight
		egen mean = mean(conflict_weight) if sample==1
		gen within_weight=1+conflict_weight-mean if sample==1
		label var within_weight "Within-sample probability weight"
		drop mean

		save Data/RebelGroupsData, replace
			
	
	// CLEAN AND LABEL VARIABLES
	
		//Cleaning
		gen lgdppc = ln(gdpcap1980ppp)
		replace sustainactiv2yr=0 if  sustainactiv2yr==.
		destring yeardefunct, replace
	
		//Label variables
		label var id "Group ID"
		label var conflict_id "Conflict ID"
		label var groupname "Group Name"
		label var country "Country of Origin"
		label var yearfounded "Year Group Founded"
		label var yeardefunct "Year Group Defunct"
		label var yearsactive "Total Number of Years Active"
		label var sustainactiv2yr "Sustained Militancy for at least 2 years dummy"
		label var sustainactiv1yr "Sustained Militancy for at least 1 year dummy"
		label var maxgroupsize "Estimated Maximum Group Size"
		label var recruitment "Type of Recruitment"
		label var childsoldier "Degree of Child Soldier Activity"
		label var childsoldieryoung "Degree of Child Soldier <15 yrs old Activity"
		label var remuneration "Rumuneration of forces (type)"
		label var broadsupport "Degree of support among population (0-2)"
		label var resourceamt "Group Resource Wealth (0-2)"
		label var nominalgdpcap1980 "Nominal 1980 GDP/Capita" 
		label var gdpcap1980ppp "1980 GDP/Capita PPP"
		label var lgdppc "log 1980 GDP/Capita PPP"
		label var soldierassumption "Assumptions Made for C.S Variable"
		label var keyvarassumption "Assumptions Made for Key Variables"
		label var intenseconflictdum "High Intensity Conflict Dummy"
		
		//Label Variable Values
		
		label define childsoldier 0 "less than 5%" 1 "6-19%" 2 "20-39%" 3 "40-59%" 4 "60-80%"
		label values childsoldier childsoldier

		label define childsoldieryoung 0 "Less than 5%" 1 "More than 5%"
		label values childsoldieryoung childsoldieryoung

		replace recruitment=1 if recruitment==2
		label define recruitment 0 "<20% recruits coerced" 1 ">20% recruits coerced"
		label values recruitment recruitment
		
		label define broadsupport 0 "No" 1 "Mixed" 2 "Yes"
		label values broadsupport broadsupport
		
		replace resourceamt=resourceamt-1
		label define resourceamt 0 "Low" 1 "Medium" 2 "High"
		label values resourceamt resourceamt
		
		label define resource 1 "Natural resources" 2 "Foreign governments" 3 "Local community" 4 "Seizure/looting, coercive taxation" 5 "private wealth domestic" 6 "private wealth foreign" 7 "smuggling-not natural resource"
		label values resource1 resource2 resource3 resource4 resource
		
	
	// VARIABLE CONSTRUCTION
	
		* Construct missing data dummy if childsoldier or childsoldieryoung is missing
		gen missingcsdum=.
		replace missingcsdum=1 if childsoldier==. | childsoldieryoung==.
		replace missingcsdum=0 if missingcsdum==.
		label var missingcsdum "Missing ChildSoldier Data Dummy"
		
		* Construct missing data dummy if recruitment is missing
		gen missingrecruitdum=.
		replace missingrecruitdum=0 if recruitment!=.
		replace missingrecruitdum=1 if recruitment==.
		label var missingrecruitdum "Missing Recruitment Data Dummy"
		
		* Construct missing data dummy if child soldier, recruitment, or broadsupport is missing
		gen missingdatadum=.
		replace missingdatadum=1 if missingrecruitdum==1 | missingcsdum==1 | broadsupport==.
		replace missingdatadum=0 if missingdatadum==.
		label var missingdata "Missing Data Dummy"
		
		* Forced/Mixed Recruitment Dummy
		replace recruitment=1 if recruitment==1 | recruitment==2
		
		* Rescaled Version of Childsoldier-  Will run from 0 to 1.  "0-5%" will code as .025, "20-40%" will code as .3, "Above 40%" will code as .5
		*X* Coding "above 40%" of troops child soldiers as .5, under the assumption that the highest plausible proportion of child soldiers in a rebel group
		* is .6 
		
		gen childsoldierscaled=childsoldier
		replace childsoldierscaled=.025 if childsoldier==0
		replace childsoldierscaled=.125 if childsoldier==1
		replace childsoldierscaled=.3 if childsoldier==2
		replace childsoldierscaled=.5 if childsoldier==3
		replace childsoldierscaled=.7 if childsoldier==4
		label var childsoldierscaled "Proportion of Child Soldiers"
		
		* Country Dummies
		gen _ugandadum=cond(country=="Uganda",1,0) 
		label var _ugandadum "Uganda Country Dummy"
		gen _somaliadum=cond(country=="Somalia",1,0)
		label var _somaliadum "Somalia Country Dummy"
		gen _cotedivoiredum=cond(country=="Cote d'Ivoire",1,0)
		label var _cotedivoiredum "Cote d'voire Country Dummy"
		gen _ethiopiadum=cond(country=="Ethiopia",1,0)
		label var _ethiopiadum "Ethiopia Country Dummy"
		gen _drcdum=cond(country=="DRC",1,0)
		labe var _drcdum "DRC Country Dummy"
		gen _senegaldum=cond(country=="Senegal",1,0)
		label var _senegaldum "Senegal Country Dummy"
		gen _malidum=cond(country=="Mali",1,0)
		label var _malidum "Mali Country Dummy"
		gen _nigeriadum=cond(country=="Nigeria",1,0)
		label var _nigeriadum "Nigeria Country Dummy"
		gen _southafricadum=cond(country=="South Africa",1,0)
		label var _southafricadum "South Africa Country Dummy"
		
		* LRA dummy
		gen LRA=cond(groupname=="LRA",1,0)
		
		* Generate the Interaction of childsoldier with the Mixed or Forced recruitment dummy (mixedforcedrecruitment).  Will call this variable childforced
		gen childforced=childsoldier*recruitment
		gen childforcedscaled=childsoldierscaled*recruitment
		gen childforced_dum = cond(childforced>0,1,0) if childforced!=.
		label var childforced "Forced Recruitment of C.S. Intensity"
		label var childforcedscaled "Forced Recruitment of C.S. Intensity (C.S. scaled)"
		label var childforced_dum "Indicator for Forced Recruitment of Children"

		* Generate funding source data
		gen nat_res=cond(resource1==1 | resource2==1 | resource3==1 | resource4==1,1,0) if resource1!=.
		gen looting=cond(resource1==4 | resource2==4 | resource3==4 | resource4==4,1,0) if resource1!=.
		gen local=cond(resource1==3 | resource2==3 | resource3==3 | resource4==3,1,0) if resource1!=.
		gen private_dom=cond(resource1==5 | resource2==5 | resource3==5 | resource4==5,1,0) if resource1!=.
		gen foreign_govt=cond(resource1==2 | resource2==2 | resource3==2 | resource4==2,1,0) if resource1!=.
		gen foreign_priv=cond(resource1==6 | resource2==6 | resource3==6 | resource4==6,1,0) if resource1!=.
		gen smuggle=cond(resource1==7 | resource2==7 | resource3==7 | resource4==7,1,0) if resource1!=.
			
		* Broad support dummy
		gen broadsupport_dum=cond(broadsupport==1 | broadsupport==2,1,0) if broadsupport!=.
		
		* Post-Cold War founding
		gen post_cold_war = cond(yearfounded>1989,1,0) if yearfounded!=.
		
		gen broadsupport_coldwar = broadsupport_dum*post_cold_war
		gen nat_res_coldwar = nat_res*post_cold_war
		gen foreign_govt_coldwar = foreign_govt*post_cold_war
	
		save Data/RebelGroupsData.dta, replace


	
//2. *FIGURES *//


// 2.1 *FIGURE 6: Distribution of age at the time of abduction in the LRA *
	
	use Data/tempdata/abduction_age, clear
	
	tw mspline prop age, xlab(5(5)45) bands(12) || mspline mn age, bands(12) lp(dash) xtitle("Age of Abduction", margin(top) size(medlarge)) ytitle("Proportion", margin(right) size(medlarge)) legend(r(2) label(1 "Age distribution of abductees (at time of abduction)") label(2 "Average proportion of population abducted, 1989-2004")) graphr(color(white)) sch(s2mono)

	*tw bar prop age, xlab(7(2)45) bc(bluishgray*1.3) blc(white) || connected mn age, m(none) mc(maroon) xtitle("Age of Abduction", margin(top) size(medlarge)) ytitle("Proportion", margin(right) size(medlarge)) legend(r(2) label(1 "Age distribution of abductees (at time of abduction)") label(2 "Average proportion of population abducted, 1989-2004")) graphr(color(white))
	
	
// 2.2 *FIGURE 7: Probability of being released in the first month of abduction, by age of abduction*

	use Data/tempdata/abductions.dta, clear

	running released_2 abd_age, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se
	sort abd_age
	tw line b abd_age || line se1 abd_age, clpat(shortdash) || line se2 abd_age, clpat(shortdash) ylab(0(.1).5) xlab(5(2)30) ytitle("Probability of release", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) graphr(color(white)) legend(off) sch(s2mono)


// 2.3 *FIGURE 8: How do rebel leaders employ abductees of different ages?*

	use Data/tempdata/individual.dta, clear

	* Months before receiving a gun
	running gun_mo abd_age, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se
	sort abd_age
	tw line b abd_age || line se1 abd_age, clpat(shortdash) || line se2 abd_age, clpat(shortdash) ylab(0(3)12) xlab(5(2)30) ytitle("Months before receiving a gun", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) graphr(color(white)) legend(off) sch(s2mono)
	cap drop b se se1 se2 
	
	* Allowed to keep your own gun
	* Imputing zero for those abducted less than two weeks
	running gun_keep_alt abd_age, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se

	sort abd_age
	tw line b abd_age || line se1 abd_age, clpat(shortdash) || line se2 abd_age if se2>0, clpat(shortdash) ylab(0(.1).5) xlab(5(2)30) ytitle("Allowed to keep own gun", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) graphr(color(white)) legend(off) sch(s2mono)
	cap drop b se se1 se2


// 2.4 *FIGURE 9: Average length of abduction, by age of abduction*

	use Data/tempdata/abductions.dta, clear

	running abd_lgth abd_age if released_2==0, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se
	sort abd_age
	tw line b abd_age if released_2==0 || line se1 abd_age if released_2==0, clpat(shortdash) || line se2 abd_age if released_2==0, clpat(shortdash) xlab(5(2)30) ytitle("Months Abducted", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) legend(off) graphr(color(white)) sch(s2mono)


// 2.5 *FIGURE 10: Ease of indoctrination and misinformation, by abduction age*

	use Data/tempdata/individual.dta, clear

	running safer_alt abd_age, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se
	sort abd_age
	tw line b abd_age || line se1 abd_age, clpat(shortdash) || line se2 abd_age if se2>-.1, clpat(shortdash) ylab(-.1(.1).2) xlab(5(2)30) ytitle("Proportion", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) graphr(color(white)) legend(off) sch(s2mono)
	cap drop b se se1 se2


	running loyal_alt abd_age, ci span(1) gen(b) gense(se) nograph
	gen se1=b+1.96*se
	gen se2=b-1.96*se
	sort abd_age
	tw line b abd_age || line se1 abd_age, clpat(shortdash) || line se2 abd_age if se2>0, clpat(shortdash) ylab(0(.1).5) xlab(5(2)30) ytitle("Proportion", size(medlarge) margin(right)) xtitle("Age of abduction", size(medlarge) margin(top)) graphr(color(white)) legend(off) sch(s2mono)
	cap drop b se se1 se2



// 2.6 *FIGURE 11: The distribution of child soldiering across 40 rebel groups (by level of coercion employed by the group)*

	use Data/RebelGroupsData.dta, clear
	gr box childsoldierscaled [pw=within_weight], over(recruitment) medm(m(Th) mfc(white)) medt(marker) box(1,fc(white)) yti("Estimated proportion of recruits under 18", margin(right)) graphregion(color(white)) scheme(s1mono)



// 3.0 *TABLES*//

// 3.1 *SUMMARY STATISTICS (not displayed in paper, but referred to in text)*

	/* Abductee attrition */

	use Data/SWAY_I&II_27Jan2009.dta, clear
		summ nosurvive if abd==1 & phase2==0
		summ nosurvive if abd==1 & phase2==1
		summ found if abd==1 & phase2==0 & sample==1 [iw=i_weight]
		summ found if abd==1 & phase2==1 & sample==1 [iw=i_weight]

	/* LRA survey data on abductees (Uganda) */
	
		* Summary statistics where abductions are the unit of analysis

		use Data/tempdata/abductions.dta, clear
			summ abd_lgth released_2 rescued esc_bat esc_ran esc_knew [iw=i_weight]
			summ abd_lgth if released==0 [iw=i_weight]
			summ rescued esc_bat esc_ran esc_knew if released==0 & (esc_ranaway+esc_bat+rescued!=0) [iw=i_weight]
	
		* Summary statistics where individuals are the unit of analysis
		use Data/tempdata/individual.dta, clear
			summ rewarded_alt stay_alt safer_alt loyal_alt command_alt magic_alt depend_alt tied carry combatant kill_sol lead gun_keep_alt gun_mo fighter threats threats_only indoctrinate ceremony beaten attacked harm_civ harm_fam abusedead if abd==1 [iw=i_weight]
			summ rewarded_alt stay_alt safer_alt loyal_alt command_alt magic_alt depend_alt tied carry combatant kill_sol lead gun_keep_alt gun_mo fighter threats threats_only indoctrinate ceremony beaten attacked harm_civ harm_fam abusedead if abd_lgth>=2 [iw=i_weight]
	
		use Data/SWAY_I&II_27Jan2009.dta, clear
			summ beaten attacked harm_civ harm_fam abusedead if abd==0 & sample==1 [iw=i_weight]

		
	/* Survey data on 12 Rebel groups */
	
		use Data/factions.dta, clear
		table faction, c(median  age_recruit_faction mean  under15 mean  under18)
		graph box age_recruit_faction, over(faction, sort(1) label(labs(medsmall))) ytitle("Age of recruitment", margin(right)) noout nofill graphr(color(white)) legend(off) scale(.8) note("C = Colombia; L = Liberia; S = Sierra Leone; U = Uganda", margin(top)) xsize(7.5)
	

// 3.2 *TABLE 1: Abduction experiences*

	gl table Table1
			cap erase Data/Output/$table.xml
			cap erase Data/Output/$table.txt
	 
		use Data/tempdata/abductions.dta, clear
		summ abd_lgth rescue esc_ran esc_knew [iw=i_weight] if released_2==0
	
		use Data/tempdata/individual.dta, clear
		summ rewarded_alt indoc threats_only harm_fam abusedead gun_keep_alt gun_mo depend_alt safer_alt loyal_alt magic_alt stay_alt command_alt [iw=i_weight] 
		summ rewarded_alt indoc threats_only harm_fam abusedead gun_keep_alt gun_mo depend_alt safer_alt loyal_alt magic_alt stay_alt command_alt [iw=i_weight] 
		summ rewarded_alt indoc threats_only harm_fam abusedead gun_keep_alt gun_mo depend_alt safer_alt loyal_alt magic_alt stay_alt command_alt [iw=i_weight] 
	 
		use Data/tempdata/abductions.dta, clear
		
		svyset [pw=i_weight], strata(stratum) psu(id)
		
		* Linear Age
		local lbl : variable label abd_lgth
		qui svy: reg abd_lgth abd_age $ctrl if released_2==0
			outreg2 abd_age using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons replace ctitle(`lbl')

		foreach y of varlist rescue esc_ran esc_knew {
			local lbl : variable label `y'
			qui svy: reg `y' abd_age $ctrl
				outreg2 abd_age using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons ctitle(`lbl')
			}
			
		* Quadratic Age
		local lbl : variable label abd_lgth
		qui svy: reg abd_lgth abd_age abd_age_2 $ctrl if released_2==0
			outreg2 abd_age abd_age_2 using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons ctitle(`lbl')
		 
		foreach y of varlist rescue esc_ran esc_knew {
			local lbl : variable label `y'
			qui svy: reg `y' abd_age abd_age_2 $ctrl
				outreg2 abd_age abd_age_2 using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons  ctitle(`lbl')
			}

		use Data/tempdata/individual.dta, clear
		
		svyset [pw=i_weight], strata(stratum) psu(camp)

		* Linear Age
		foreach y of varlist rewarded_alt indoc threats_only harm_fam abusedead gun_keep_alt gun_mo depend_alt safer_alt loyal_alt  magic_alt stay_alt command_alt {
			local lbl : variable label `y'
			qui svy: reg `y' abd_age $ctrl
				outreg2 abd_age using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons ctitle(`lbl')
			}
			
		* Quadratic Age	
		foreach y of varlist rewarded_alt indoc threats_only harm_fam abusedead gun_keep_alt gun_mo depend_alt safer_alt loyal_alt magic_alt stay_alt command_alt {
			local lbl : variable label `y'
			qui svy: reg `y' abd_age abd_age_2 $ctrl
				outreg2 abd_age abd_age_2 using Data/Output/$table.xml, excel br bdec(3) aster(se) label nocons ctitle(`lbl')
			}

		cap erase Data/Output/$table.txt	
		
	

// 3.3 *TABLE 2: Correlates of child coercion across rebel groups*
	
	use Data/RebelGroupsData.dta, clear
		
		gl table Table2_Col1
			cap erase Data/Output/$table.xml
			cap erase Data/Output/$table.txt
	  
			cap matrix drop E
			matrix E = [0/0]
		
			foreach y in broadsupport_dum nat_res foreign_govt foreign_govt_coldwar post_cold_war sustainactiv2yr { 
				sum `y' if sample==1
					local `y'1 = r(mean)
					local `y'2 = r(sd)
					
				matrix mat`y'c  = (``y'1', ``y'2')
					matrix E = E/mat`y'c
			}
		
		* Save table	
			local cnames  `"  "Mean"  "Std. Dev." "'
			local rname
			foreach y in broadsupport_dum nat_res foreign_govt foreign_govt_coldwar post_cold_war sustainactiv2yr {	
				local lbl : variable label `y'
				local rname `" `rname' "`lbl'" "'
			} 
			*"
			
			xml_tab E, save("Data/Output/$table.xml") noisily  cnames(`cnames') rnames(`rname')  font("Times New Roman" 10) ///
			format((SCLR0) (SCCR0 NBCR2 NBCR2 NBCR2 NBCR2 NBCR2))

		gl table Table2_Col2to8
			cap erase Data/Output/$table.xml
			cap erase Data/Output/$table.txt
	   
		foreach y of varlist childforced_dum {
		
			local lbl : variable label childforced_dum
		
			qui reg `y' broadsupport_dum [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
				
			qui reg `y' nat_res [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
			
			qui reg `y' foreign_govt [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
		
			qui reg `y' broadsupport_dum nat_res foreign_govt [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
			
			qui reg `y' broadsupport_dum nat_res foreign_govt sustainactiv2yr [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
				
			qui reg `y' broadsupport_dum nat_res foreign_govt sustainactiv2yr if LRA!=1 [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append	 ctitle(`lbl')
			
			qui reg `y' broadsupport_dum nat_res foreign_govt foreign_govt_coldwar post_cold_war sustainactiv2yr [pw=within_weight]
				outreg2 using Data/Output/$table.xml, excel label bdec(2) br append ctitle(`lbl')
	 
		}

		cap erase Data/Output/$table.txt
	
